pub enum Error {
FileRead(PathBuf, Error),
FileContentsMalformed,
SystemCall(Error),
}Expand description
An error that occurred while trying to get the process stats.
Variants
FileRead(PathBuf, Error)
A file’s contents could not be read successfully. The file that could not be read is specified by
the PathBuf parameter.
FileContentsMalformed
A file’s contents were in an unexpected format
SystemCall(Error)
A system-native function returned an error code.